==> openshift-model-console-6.9.0-sources.jar: io/fabric8/openshift/api/model/console/v1alpha1/ConsolePluginProxyFluent.java <==
package io.fabric8.openshift.api.model.console.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ConsolePluginProxyFluent<A extends ConsolePluginProxyFluent<A>> extends BaseFluent<A>{
  public ConsolePluginProxyFluent() {
  }
  
  public ConsolePluginProxyFluent(ConsolePluginProxy instance) {
    this.copyInstance(instance);
  }
  private String alias;
  private Boolean authorize;
  private String caCertificate;
  private ConsolePluginProxyServiceConfigBuilder service;
  private String type;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ConsolePluginProxy instance) {
    instance = (instance != null ? instance : new ConsolePluginProxy());
  
    if (instance != null) {
        this.withAlias(instance.getAlias());
        this.withAuthorize(instance.getAuthorize());
        this.withCaCertificate(instance.getCaCertificate());
        this.withService(instance.getService());
        this.withType(instance.getType());
        this.withAlias(instance.getAlias());
        this.withAuthorize(instance.getAuthorize());
        this.withCaCertificate(instance.getCaCertificate());
        this.withService(instance.getService());
        this.withType(instance.getType());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getAlias() {
    return this.alias;
  }
  
  public A withAlias(String alias) {
    this.alias=alias; return (A) this;
  }
  
  public boolean hasAlias() {
    return this.alias != null;
  }
  
  public Boolean getAuthorize() {
    return this.authorize;
  }
  
  public A withAuthorize(Boolean authorize) {
    this.authorize=authorize; return (A) this;
  }
  
  public boolean hasAuthorize() {
    return this.authorize != null;
  }
  
  public String getCaCertificate() {
    return this.caCertificate;
  }
  
  public A withCaCertificate(String caCertificate) {
    this.caCertificate=caCertificate; return (A) this;
  }
  
  public boolean hasCaCertificate() {
    return this.caCertificate != null;
  }
  
  public ConsolePluginProxyServiceConfig buildService() {
    return this.service!=null ?this.service.build():null;
  }
  
  public A withService(ConsolePluginProxyServiceConfig service) {
    _visitables.get("service").remove(this.service);
    if (service!=null){ this.service= new ConsolePluginProxyServiceConfigBuilder(service); _visitables.get("service").add(this.service);} else { this.service = null; _visitables.get("service").remove(this.service); } return (A) this;
  }
  
  public boolean hasService() {
    return this.service != null;
  }
  
  public A withNewService(String name,String namespace,Integer port) {
    return (A)withService(new ConsolePluginProxyServiceConfig(name, namespace, port));
  }
  
  public ServiceNested<A> withNewService() {
    return new ServiceNested(null);
  }
  
  public ServiceNested<A> withNewServiceLike(ConsolePluginProxyServiceConfig item) {
    return new ServiceNested(item);
  }
  
  public ServiceNested<A> editService() {
    return withNewServiceLike(java.util.Optional.ofNullable(buildService()).orElse(null));
  }
  
  public ServiceNested<A> editOrNewService() {
    return withNewServiceLike(java.util.Optional.ofNullable(buildService()).orElse(new ConsolePluginProxyServiceConfigBuilder().build()));
  }
  
  public ServiceNested<A> editOrNewServiceLike(ConsolePluginProxyServiceConfig item) {
    return withNewServiceLike(java.util.Optional.ofNullable(buildService()).orElse(item));
  }
  
  public String getType() {
    return this.type;
  }
  
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  
  public boolean hasType() {
    return this.type != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConsolePluginProxyFluent that = (ConsolePluginProxyFluent) o;
    if (!java.util.Objects.equals(alias, that.alias)) return false;
  
    if (!java.util.Objects.equals(authorize, that.authorize)) return false;
  
    if (!java.util.Objects.equals(caCertificate, that.caCertificate)) return false;
  
    if (!java.util.Objects.equals(service, that.service)) return false;
  
    if (!java.util.Objects.equals(type, that.type)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(alias,  authorize,  caCertificate,  service,  type,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (alias != null) { sb.append("alias:"); sb.append(alias + ","); }
    if (authorize != null) { sb.append("authorize:"); sb.append(authorize + ","); }
    if (caCertificate != null) { sb.append("caCertificate:"); sb.append(caCertificate + ","); }
    if (service != null) { sb.append("service:"); sb.append(service + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withAuthorize() {
    return withAuthorize(true);
  }
  public class ServiceNested<N> extends ConsolePluginProxyServiceConfigFluent<ServiceNested<N>> implements Nested<N>{
    ServiceNested(ConsolePluginProxyServiceConfig item) {
      this.builder = new ConsolePluginProxyServiceConfigBuilder(this, item);
    }
    ConsolePluginProxyServiceConfigBuilder builder;
    
    public N and() {
      return (N) ConsolePluginProxyFluent.this.withService(builder.build());
    }
    
    public N endService() {
      return and();
    }
    
  
  }

}

==> openshift-model-console-6.9.1-sources.jar: io/fabric8/openshift/api/model/console/v1alpha1/ConsolePluginProxyFluent.java <==
package io.fabric8.openshift.api.model.console.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ConsolePluginProxyFluent<A extends ConsolePluginProxyFluent<A>> extends BaseFluent<A>{
  public ConsolePluginProxyFluent() {
  }
  
  public ConsolePluginProxyFluent(ConsolePluginProxy instance) {
    this.copyInstance(instance);
  }
  private String alias;
  private Boolean authorize;
  private String caCertificate;
  private ConsolePluginProxyServiceConfigBuilder service;
  private String type;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ConsolePluginProxy instance) {
    instance = (instance != null ? instance : new ConsolePluginProxy());
    if (instance != null) {
          this.withAlias(instance.getAlias());
          this.withAuthorize(instance.getAuthorize());
          this.withCaCertificate(instance.getCaCertificate());
          this.withService(instance.getService());
          this.withType(instance.getType());
          this.withAlias(instance.getAlias());
          this.withAuthorize(instance.getAuthorize());
          this.withCaCertificate(instance.getCaCertificate());
          this.withService(instance.getService());
          this.withType(instance.getType());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getAlias() {
    return this.alias;
  }
  
  public A withAlias(String alias) {
    this.alias = alias;
    return (A) this;
  }
  
  public boolean hasAlias() {
    return this.alias != null;
  }
  
  public Boolean getAuthorize() {
    return this.authorize;
  }
  
  public A withAuthorize(Boolean authorize) {
    this.authorize = authorize;
    return (A) this;
  }
  
  public boolean hasAuthorize() {
    return this.authorize != null;
  }
  
  public String getCaCertificate() {
    return this.caCertificate;
  }
  
  public A withCaCertificate(String caCertificate) {
    this.caCertificate = caCertificate;
    return (A) this;
  }
  
  public boolean hasCaCertificate() {
    return this.caCertificate != null;
  }
  
  public ConsolePluginProxyServiceConfig buildService() {
    return this.service != null ? this.service.build() : null;
  }
  
  public A withService(ConsolePluginProxyServiceConfig service) {
    this._visitables.remove(this.service);
    if (service != null) {
        this.service = new ConsolePluginProxyServiceConfigBuilder(service);
        this._visitables.get("service").add(this.service);
    } else {
        this.service = null;
        this._visitables.get("service").remove(this.service);
    }
    return (A) this;
  }
  
  public boolean hasService() {
    return this.service != null;
  }
  
  public A withNewService(String name,String namespace,Integer port) {
    return (A)withService(new ConsolePluginProxyServiceConfig(name, namespace, port));
  }
  
  public ServiceNested<A> withNewService() {
    return new ServiceNested(null);
  }
  
  public ServiceNested<A> withNewServiceLike(ConsolePluginProxyServiceConfig item) {
    return new ServiceNested(item);
  }
  
  public ServiceNested<A> editService() {
    return withNewServiceLike(java.util.Optional.ofNullable(buildService()).orElse(null));
  }
  
  public ServiceNested<A> editOrNewService() {
    return withNewServiceLike(java.util.Optional.ofNullable(buildService()).orElse(new ConsolePluginProxyServiceConfigBuilder().build()));
  }
  
  public ServiceNested<A> editOrNewServiceLike(ConsolePluginProxyServiceConfig item) {
    return withNewServiceLike(java.util.Optional.ofNullable(buildService()).orElse(item));
  }
  
  public String getType() {
    return this.type;
  }
  
  public A withType(String type) {
    this.type = type;
    return (A) this;
  }
  
  public boolean hasType() {
    return this.type != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConsolePluginProxyFluent that = (ConsolePluginProxyFluent) o;
    if (!java.util.Objects.equals(alias, that.alias)) return false;
    if (!java.util.Objects.equals(authorize, that.authorize)) return false;
    if (!java.util.Objects.equals(caCertificate, that.caCertificate)) return false;
    if (!java.util.Objects.equals(service, that.service)) return false;
    if (!java.util.Objects.equals(type, that.type)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(alias,  authorize,  caCertificate,  service,  type,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (alias != null) { sb.append("alias:"); sb.append(alias + ","); }
    if (authorize != null) { sb.append("authorize:"); sb.append(authorize + ","); }
    if (caCertificate != null) { sb.append("caCertificate:"); sb.append(caCertificate + ","); }
    if (service != null) { sb.append("service:"); sb.append(service + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withAuthorize() {
    return withAuthorize(true);
  }
  public class ServiceNested<N> extends ConsolePluginProxyServiceConfigFluent<ServiceNested<N>> implements Nested<N>{
    ServiceNested(ConsolePluginProxyServiceConfig item) {
      this.builder = new ConsolePluginProxyServiceConfigBuilder(this, item);
    }
    ConsolePluginProxyServiceConfigBuilder builder;
    
    public N and() {
      return (N) ConsolePluginProxyFluent.this.withService(builder.build());
    }
    
    public N endService() {
      return and();
    }
    
  
  }

}
